//****************************************************************************
//	
//	Copyright 2017 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : panel.cpp
//
//	Project	 : LVDS Controller Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	08/07/17	  1.0		Original Release
//
//****************************************************************************

#include "stdafx.h"
#include <stdio.h>
#include <stdlib.h>  
#include <windows.h>
#include "lvdsControllerDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0

int _tmain(int argc, _TCHAR* argv[])
{
    int dllReturn = 0;

    printf("LVDS Controller Application : panel\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    dllReturn = InitializeSession();

    if (dllReturn)
    {
        printf("Error initializing session with code %d.\n", dllReturn);
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    for (int i = 0; i < MAX_BL_FREQ_OPTIONS; i++)
    {
        if (blSetFrequency(i))
        {
            printf("\nError setting frequency with code %d.\n", dllReturn);
            exit(dllReturn);
        }

        for (int j = 1; j < MAX_BL_DUTY_OPTIONS; j++)
        {
           if (blSetDutyCycle(j))
           {
               printf("\nError setting duty cycle with code %d.\n", dllReturn);
               exit(dllReturn);
           }

           Sleep(2000);
        }
    }

    if (blSetFrequency(BL_FREQ_225))
    {
        printf("\nError setting frequency with code %d.\n", dllReturn);
        exit(dllReturn);
    }

    if (blSetDutyCycle(BL_DUTY_75))
    {
        printf("\nError setting duty cycle with code %d\n", dllReturn);
        exit(dllReturn);
    }

    printf("Panel will be disabled in 2 seconds.\n");

    Sleep(2000);

    if (blOnOff(BL_OFF))
        printf("\nError turning backlight off.\n\n");

    Sleep(2000);

    printf("Panel enabled again.\n");

    if (blOnOff(BL_ON))
        printf("\nError turning backlight on.\n\n");

    dllReturn = CloseSession();

    if (dllReturn)
    {
        printf("Error closing session with code %d.\n", dllReturn);
        exit(dllReturn);
    }

    printf("Device closed.\n\n");

    return dllReturn;
}
